==> quantlib_1.9.1.orig.tar.gz: QuantLib-1.9.1/ql/experimental/finitedifferences/bsmrndcalculator.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2015 Johannes Goettker-Schnetmann
 Copyright (C) 2015 Klaus Spanderen

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file bsmrndcalculator.hpp
    \brief risk neutral terminal density calculator for the
           Black-Scholes-Merton model with constant volatility
*/

#ifndef quantlib_bsm_risk_neutral_density_calculator_hpp
#define quantlib_bsm_risk_neutral_density_calculator_hpp

#include <ql/experimental/finitedifferences/riskneutraldensitycalculator.hpp>
#include <boost/shared_ptr.hpp>

namespace QuantLib {
    class GeneralizedBlackScholesProcess;

    class BSMRNDCalculator : public RiskNeutralDensityCalculator {
    public:
        BSMRNDCalculator(
            const boost::shared_ptr<GeneralizedBlackScholesProcess>& process);

        // x = ln(S)
        Real pdf(Real x, Time t) const;
        Real cdf(Real x, Time t) const;
        Real invcdf(Real q, Time t) const;

    private:
        std::pair<Real, Volatility> distributionParams(Real x, Time t) const;

        const boost::shared_ptr<GeneralizedBlackScholesProcess> process_;
    };
}

#endif

==> quantlib_1.15.orig.tar.gz: QuantLib-1.15/ql/experimental/finitedifferences/bsmrndcalculator.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2015 Johannes Goettker-Schnetmann
 Copyright (C) 2015 Klaus Spanderen

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file bsmrndcalculator.hpp
    \brief risk neutral terminal density calculator for the
           Black-Scholes-Merton model with constant volatility
*/

#ifndef quantlib_bsm_risk_neutral_density_calculator_hpp
#define quantlib_bsm_risk_neutral_density_calculator_hpp

#include <ql/experimental/finitedifferences/riskneutraldensitycalculator.hpp>
#include <ql/shared_ptr.hpp>

namespace QuantLib {
    class GeneralizedBlackScholesProcess;

    class BSMRNDCalculator : public RiskNeutralDensityCalculator {
    public:
        explicit BSMRNDCalculator(
            const ext::shared_ptr<GeneralizedBlackScholesProcess>& process);

        // x = ln(S)
        Real pdf(Real x, Time t) const;
        Real cdf(Real x, Time t) const;
        Real invcdf(Real q, Time t) const;

    private:
        std::pair<Real, Volatility> distributionParams(Real x, Time t) const;

        const ext::shared_ptr<GeneralizedBlackScholesProcess> process_;
    };
}

#endif
